## 7.0.8 (2022-08-04)

Various pyvmomi improvements (#8469)

Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>
Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 7.0.7 (2022-04-06)

Update pyVmomi stubs (#7599)

* Add generic base class `DynamicData`
* Add missing `key` prop to `OptionValue`
* Fix `MethodFault` not inheriting from `Exception`
* Fix `RetrieveOptions` default `maxObjects` type and default

## 7.0.6 (2022-03-29)

Add a few classes to vmodl and vmodl.fault (#7565)

## 7.0.5 (2022-03-09)

Remove Python 2 support from some third-party distributions (#7466)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 7.0.4 (2022-01-31)

Upgrade black version (#7089)

## 7.0.3 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 7.0.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 7.0.0 (2021-09-19)

Update third-party package versions (#5996)

